@@ -22,7 +22,7 @@ if ($file eq '') {
 }
 
 my $dbusername = "root";
-my $dbpassword = "rootpass";
+my $dbpassword = "";
 my $dbh = DBI->connect("DBI:mysql:radius", $dbusername, $dbpassword) || die "Cound not connect to radius database as $dbusername\n";
 
 my $lastrow = 0;
