@@ -228,7 +228,12 @@ static int unix_pass(char *name, char *passwd)
 static int rad_check_password(AUTH_REQ *authreq, int activefd,
 	VALUE_PAIR *check_item,
 	VALUE_PAIR *namepair,
-	char *pw_digest, char **user_msg, char *userpass)
+	char *pw_digest, char **user_msg, char *userpass
+#ifdef USEMYSQL
+	, char *dbpass)
+#else
+	);
+#endif
 {
 	char		string[AUTH_STRING_LEN];
 	char		name[AUTH_STRING_LEN];
@@ -348,6 +353,7 @@ static int rad_check_password(AUTH_REQ *authreq, int activefd,
 /* Since we read the users stuff into the structures it acts as if AUTHTYPE was local */
 #ifdef USEMYSQL
 
+	strncpy(dbpass, password_pair->strvalue, 127);
 	if (password_pair == NULL || strcmp(password_pair->strvalue, string)!=0)
 		result = -1;
 
@@ -551,6 +557,9 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 	int		result, r;
 	char		pw_digest[16];
 	char		userpass[128];
+#ifdef USEMYSQL
+	char		dbpass[128];
+#endif
 	char		umsg[128];
 	char		*user_msg;
 	char		*ptr;
@@ -616,6 +625,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 		rad_send_reply(PW_AUTHENTICATION_REJECT, authreq,
 			proxy_pairs, NULL, activefd);
 		pairfree(proxy_pairs);
+		pairfree(user_check);
 		pairfree(user_reply);
 		authfree(authreq);
 		return -1;
@@ -631,7 +641,12 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 				break;
 
 		result = rad_check_password(authreq, activefd, user_check,
-			namepair, pw_digest, &user_msg, userpass);
+			namepair, pw_digest, &user_msg, userpass
+#ifdef USEMYSQL
+			, dbpass);
+#else
+			);
+#endif
 
 		if (result > 0) {
 			/*
@@ -641,6 +656,7 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			 */
 			authfree(authreq);
 			pairfree(proxy_pairs);
+			pairfree(user_check);
 			pairfree(user_reply);
 			return -1;
 		}
@@ -661,8 +677,15 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 			user_reply, user_msg, activefd);
 		if (log_auth) {
 			log(L_AUTH,
+#ifdef USEMYSQL
+				"Login incorrect: [%s/%s] Password should be '%s' (%s)",
+#else
 				"Login incorrect: [%s/%s] (%s)",
+#endif
 				namepair->strvalue, userpass,
+#ifdef USEMYSQL
+				dbpass,
+#endif
 				auth_name(authreq, 1));
 		}
 	}
@@ -685,13 +708,67 @@ int rad_authenticate(AUTH_REQ *authreq, int activefd)
 				user_msg = umsg;
 				result = -1;
 				rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
-				log(L_ERR, "Unauthorized port Attempt: [%s] (from nas %s) type %s", namepair->strvalue, nas_name2(authreq), ptype);
+				log(L_ERR, "Unauthorized port attempt: [%s] (%s) type %s", namepair->strvalue, auth_name(authreq, 1), ptype);
 			}
 			
 		}
 	}
 
 
+	if (result >=0 && (check_item = pairfind(user_check, PW_MAX_HOURS)) != NULL) {
+
+		MYSQL_ROW	row;
+		MYSQL_RES	*sqlresult;
+		char		querystr[256];
+		unsigned long	allowed = 0;
+		unsigned long	used = 0;
+		unsigned long	diff = 0;
+
+		allowed = check_item->lvalue * 3600;
+		sprintf(querystr, "SELECT SUM(AcctSessionTime) FROM radacct WHERE UserName = '%s' and AcctStartTime >= CONCAT(YEAR(NOW()),'-',MONTH(NOW()),'-01 00:00:00') AND AcctStartTime <= CONCAT(YEAR(NOW()),'-',MONTH(NOW())+1,'-01 00:00:00')", namepair->strvalue);
+		if (sqltrace)
+			DEBUG(querystr);
+		mysql_query(MySock, querystr);
+		if (!(sqlresult = mysql_store_result(MySock)) && mysql_num_fields(MySock)) {
+			log(L_ERR,"MYSQL Error: Cannot get result");
+			log(L_ERR,"MYSQL error: %s",mysql_error(MySock));
+			mysql_close(MySock);
+			MySock = NULL;
+		} else {
+			row = mysql_fetch_row(sqlresult);
+			used = atol(row[0]);
+			mysql_free_result(sqlresult);
+		}
+		
+		if (used >= allowed) {
+			sprintf(umsg, "\r\nYour account has reached it limit of %d hours\r\n\n", (int)check_item->lvalue);
+			user_msg = umsg;
+			result = -1;
+			rad_send_reply(PW_AUTHENTICATION_REJECT, authreq, user_reply, user_msg, activefd);
+			log(L_ERR, "Usage limit of %d hours reached: [%s] (%s)", (int)check_item->lvalue, namepair->strvalue, auth_name(authreq, 1));
+		}
+			
+		if (result >=0 && (reply_item = pairfind(user_reply, PW_SESSION_TIMEOUT)) != NULL) {
+			diff = allowed - used;
+			if (diff < reply_item->lvalue)
+				reply_item->lvalue = diff;
+		} else {
+			if (!(reply_item = malloc(sizeof(VALUE_PAIR)))){
+				log(L_ERR|L_CONS, "no memory");
+				exit(1);
+			}
+			memset(reply_item, 0, sizeof(VALUE_PAIR));
+			reply_item->attribute = PW_SESSION_TIMEOUT;
+			strcpy(reply_item->name, "Session-Timeout");
+			reply_item->type = PW_TYPE_INTEGER;
+			reply_item->length = 4;
+			reply_item->lvalue = diff;
+			pairadd(&user_reply, reply_item);
+		}
+
+	}
+
+
 	if (result >= 0 &&
 	   (check_item = pairfind(user_check, PW_SIMULTANEOUS_USE)) != NULL) {
 #if 0 /* DEBUG */
