@@ -484,7 +484,7 @@ int mysql_userparse(VALUE_PAIR **first_pair, MYSQL_ROW row, int mode) {
 		return 0;
 
 	if((pair = (VALUE_PAIR *)malloc(sizeof(VALUE_PAIR))) == (VALUE_PAIR *)NULL) {
-		log(L_CONS|L_ERR, "no memory");
+		log(L_CONS|L_ERR, "mysql_userparse: no memory");
 		exit(1);
 	}
 	strcpy(pair->name, attr->name);
@@ -584,8 +584,7 @@ int mysql_userparse(VALUE_PAIR **first_pair, MYSQL_ROW row, int mode) {
 #endif
                         return(-1);
 	}
-                        pairadd(first_pair, pair);
-
+	pairadd(first_pair, pair);
 
 	return 0;
 }
@@ -656,6 +655,7 @@ int mysql_getvpdata(char *table, VALUE_PAIR **vp, char *user, int mode) {
 
 			if (mysql_userparse(vp, row, PW_VP_REPLY) != 0) {
 		 		log(L_ERR|L_CONS, "Error getting data from MySQL");
+				mysql_free_result(result);
 				return -1;
 			}
 		}
