@@ -54,7 +54,7 @@ int rad_send_reply(int code, AUTH_REQ *authreq, VALUE_PAIR *oreply,
 	switch(code) {
 		case PW_PASSWORD_REJECT:
 		case PW_AUTHENTICATION_REJECT:
-			what = "Reject";
+			what = "Access Reject";
 			/*
 			 *	Also delete all reply attributes
 			 *	except proxy-pair and port-message.
@@ -67,7 +67,7 @@ int rad_send_reply(int code, AUTH_REQ *authreq, VALUE_PAIR *oreply,
 			what = "Challenge";
 			break;
 		case PW_AUTHENTICATION_ACK:
-			what = "Ack";
+			what = "Access Ack";
 			break;
 		case PW_ACCOUNTING_RESPONSE:
 			what = "Accounting Ack";
@@ -320,6 +320,7 @@ AUTH_REQ	*radrecv(UINT4 host, u_short udp_port,
 {
 	u_char		*ptr;
 	AUTH_HDR	*auth;
+	char		*what;
 	int		totallen;
 	int		attribute;
 	int		attrlen;
@@ -348,8 +349,21 @@ AUTH_REQ	*radrecv(UINT4 host, u_short udp_port,
 	totallen = ntohs(auth->length);
 	if (length > totallen) length = totallen;
 
-	DEBUG("radrecv: Request from host %lx code=%d, id=%d, length=%d",
-				(u_long)host, auth->code, auth->id, totallen);
+
+	switch(auth->code) {
+		case PW_AUTHENTICATION_REQUEST:
+			what = "Access Request";
+			break;
+		case PW_ACCOUNTING_REQUEST:
+			what = "Accounting Request";
+			break;
+		default:
+			what = "Request";
+			break;
+	}
+		
+	DEBUG("radrecv: %s from host %lx code=%d, id=%d, length=%d",
+				what, (u_long)host, auth->code, auth->id, totallen);
 
 	/*
 	 *	Fill header fields
