@@ -139,6 +139,8 @@ typedef struct pw_auth_hdr {
 #define PW_HINT				1040
 #define PAM_AUTH_ATTR			1041
 #define PW_LOGIN_TIME			1042
+#define PW_RADIUS_OPERATOR		2000
+#define PW_MAX_HOURS			2001
 
 /*
  *	INTEGER TRANSLATIONS
